%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script runs the programs to generate a response to David Rosnick's 
% criticisms of Farmer's 2010 JEDC paper, "The Stock Matket Crash of 2008 
% Caused the Great Recession"
% (c) Roger E A Farmer, July 2013
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;
clear all;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This section computes comparative MSEs 
% Set Number to the maximum number of quarters to compute MSE error ratios
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Number = 12;   
MseUniv = zeros(Number,2);
MseVecm = zeros(Number,2);
compare = 0;
% Set compare = 1 for Vecm comparisons and to reproduce David Rosnick's
% Results
% Default is bivariate Var (compare =0)
for F =  1:Number
    [o] = unemploymentAndStocks(F,compare,1);
    MseUniv(F,1) = mean(o.xfuE(:,1).^2);   % Unemployment
    MseVecm(F,1) = mean(o.xfvE(:,1).^2);   % Unemployment
    MseUniv(F,2) = mean(o.xfuE(:,2).^2);   % Stock Market 
    MseVecm(F,2) = mean(o.xfvE(:,2).^2);   % Stock Market  
end
figure(4)
plot(MseVecm(:,1)./MseUniv(:,1),'Linewidth',4);
xlabel('The MSE ratio against the forecast horizon','Fontsize',20);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute frequency ditributions for H-step ahead MSE distributions
% Set H to number of steps ahead for  forecast error graph
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
H = 1;      
[o1] = unemploymentAndStocks(H,compare);
figure(5);
plot(o1.xfuUE,o1.fuUE,'Linewidth',2.5);
hold on;
plot(o1.xfvUE,o1.fvUE,'r-o','LineWidth',2.5);
line1 = 0:0.1:7;
plot(zeros(size(line1)),line1,'k','LineWidth',2.5);
xlabel('Unemployment','Fontsize',20)
h_legend = legend('Without Stock Market Wealth','With Stock Market Wealth','Location','NorthWest');
set(h_legend,'FontSize',14);
xlabel('1-Step Ahead Forecast Errors','Fontsize',20);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
